chess_premove library
Classes
Exceptions / Errors
- InvalidPremoveTurnException
- Custom exception thrown when a user attempts to register a premove during their own turn.
- PremoveSpamException
- Custom exception thrown to prevent UI freeze on the Web due to rapid spam clicks (Throttling).